<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Eraro dum (mal)aktivigo de adresaro.",
"id is not set." => "identigilo ne agordiĝis.",
"Cannot update addressbook with an empty name." => "Ne eblas ĝisdatigi adresaron kun malplena nomo.",
"No category name given." => "Ne doniĝis nomo de kategorio.",
"Error adding group." => "Eraro dum aldono de grupo.",
"Group ID missing from request." => "Grupidentigilo mankas en peto.",
"Contact ID missing from request." => "Kontaktidentigilo mankas en peto.",
"No ID provided" => "Neniu identigilo proviziĝis.",
"Error setting checksum." => "Eraro dum agordado de kontrolsumo.",
"No categories selected for deletion." => "Neniu kategorio elektiĝis por forigi.",
"No address books found." => "Neniu adresaro troviĝis.",
"No contacts found." => "Neniu kontakto troviĝis.",
"element name is not set." => "eronomo ne agordiĝis.",
"checksum is not set." => "kontrolsumo ne agordiĝis.",
"Information about vCard is incorrect. Please reload the page." => "Informo pri vCard estas malĝusta. Bonvolu reŝargi la paĝon.",
"Couldn't find vCard for %d." => "Ne troviĝis vCard-on por %d.",
"Information about vCard is incorrect. Please reload the page: " => "Informo pri vCard malĝustas. Bonvolu reŝargi la paĝon:",
"Something went FUBAR. " => "Io FUBAR-is.",
"Cannot save property of type \"%s\" as array" => "Ne povis konserviĝi propraĵo \"%s\"-tipa kiel matrico",
"Missing IM parameter." => "Mankas tujmesaĝada parametro.",
"Unknown IM: " => "Nekonata tujmesaĝado:",
"No contact ID was submitted." => "Neniu kontaktidentigilo sendiĝis.",
"Error reading contact photo." => "Eraro dum lego de kontakta foto.",
"Error saving temporary file." => "Eraro dum konservado de provizora dosiero.",
"The loading photo is not valid." => "La alŝutata foto ne validas.",
"Contact ID is missing." => "Kontaktidentigilo mankas.",
"No photo path was submitted." => "Neniu vojo al foto sendiĝis.",
"File doesn't exist:" => "Dosiero ne ekzistas:",
"Error loading image." => "Eraro dum ŝargado de bildo.",
"Error getting contact object." => "Eraro dum ekhaviĝis kontakta objekto.",
"Error getting PHOTO property." => "Eraro dum ekhaviĝis la propraĵon PHOTO.",
"Error saving contact." => "Eraro dum konserviĝis kontakto.",
"Error resizing image" => "Eraro dum aligrandiĝis bildo",
"Error cropping image" => "Eraro dum stuciĝis bildo.",
"Error creating temporary image" => "Eraro dum kreiĝis provizora bildo.",
"Error finding image: " => "Eraro dum serĉo de bildo: ",
"Key is not set for: " => "Klavo ne agordiĝis por:",
"Value is not set for: " => "Valoro ne agordiĝis por:",
"Could not set preference: " => "Ne eblis agordi preferon:",
"Error uploading contacts to storage." => "Eraro dum alŝutiĝis kontaktoj al konservejo.",
"There is no error, the file uploaded with success" => "Ne estas eraro, la dosiero alŝutiĝis sukcese.",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "La alŝutita dosiero transpasas la preskribon upload_max_filesize en php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "La alŝutita dosiero transpasas la preskribon MAX_FILE_SIZE kiu specifiĝis en la HTML-formularo",
"The uploaded file was only partially uploaded" => "la alŝutita dosiero nur parte alŝutiĝis",
"No file was uploaded" => "Neniu dosiero alŝutiĝis.",
"Missing a temporary folder" => "Mankas provizora dosierujo.",
"Couldn't save temporary image: " => "Ne eblis konservi provizoran bildon: ",
"Couldn't load temporary image: " => "Ne eblis ŝargi provizoran bildon: ",
"No file was uploaded. Unknown error" => "Neniu dosiero alŝutiĝis. Nekonata eraro.",
"Contacts" => "Kontaktoj",
"%d_selected_contacts" => "%d_selected_contacts",
"Add to..." => "Aldoni al...",
"Remove from..." => "Forigi el...",
"Add group..." => "Aldoni grupon...",
"Indexing contacts" => "Indeksante kontaktojn",
"Select photo" => "Elekti foton",
"Network or server error. Please inform administrator." => "Reta aŭ servila eraro. Bonvolu sciigi al la administranto.",
"Error adding to group." => "Eraro dum aldono al grupo.",
"Error removing from group." => "Eraro dum forigo el grupo.",
"There was an error opening a mail composer." => "Eraro okazis dum malfermo de retpoŝtomesaĝoredaktilo.",
"Deleting done. Click here to cancel reloading." => "Forigo plenumiĝis. Klaku ĉi tie por nuligi reŝargon.",
"Add address book" => "Aldoni adresaron",
"Import done. Click here to cancel reloading." => "Enporto plenumiĝis. Klaku ĉi tien por nuligi reŝargon.",
"Not all files uploaded. Retrying..." => "Ne ĉiuj dosieroj alŝutiĝis. Reprovante...",
"Something went wrong with the upload, please retry." => "Io malsukcesis dum alŝuto, bonvolu reprovi.",
"Error" => "Eraro",
"Importing from {filename}..." => "Enportante el {filename}...",
"{success} imported, {failed} failed." => "{success} enportiĝis, {failed} malsukcesis.",
"Importing..." => "Enportante...",
"Unable to upload your file as it is a directory or has 0 bytes" => "Ne eblis alŝuti vian dosieron ĉar ĝi estas dosierujo aŭ havas 0 duumokojn",
"Upload Error" => "Eraro dum alŝuto",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "La dosiero, kiun vi provas alŝuti, transpasas la maksimuman grandon por dosieraj alŝutoj en ĉi tiu servilo.",
"Upload too large" => "Alŝuto tro larĝa",
"Pending" => "Traktotaj",
"Add group" => "Aldoni grupon",
"No files selected for upload." => "Neniu dosiero elektita por alŝuto.",
"Edit profile picture" => "Redakti profilbildon",
"Error loading profile picture." => "Eraro dum ŝargado de profila bildo.",
"Enter name" => "Enigu nomon",
"Enter description" => "Enigu priskribon",
"Select addressbook" => "Elekti adresaron",
"The address book name cannot be empty." => "La nomo de la adresaro ne povas esti malplena.",
"Is this correct?" => "Ĉu ĉi tio ĝustas?",
"There was an unknown error when trying to delete this contact" => "Nekonata eraro okazis dum provo forigi ĉi tiun kontakton",
"# groups" => "# grupoj",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Iuj kontaktoj estas markitaj por forigo, sed ankoraŭ ne forigitaj. Bonvolu atendi ĝis ili foriĝos.",
"Click to undo deletion of {num} contacts" => "Klaku por malfari forigon de {num} kontaktoj",
"Cancelled deletion of {num}" => "Nuliĝis forigo de {num}",
"Contact is already in this group." => "La kontakto jam estas en ĉi tiu grupo.",
"Contacts are already in this group." => "La kontaktoj jam estas en ĉi tiu grupo.",
"Couldn't get contact list." => "Ne eblis ekhavi kontaktoliston.",
"Contact is not in this group." => "La kontakto ne estas en ĉi tiu grupo.",
"Contacts are not in this group." => "La kontaktoj ne estas en ĉi tiu grupo.",
"A group named {group} already exists" => "Grupo nomata {group} jam ekzistas",
"All" => "Ĉio",
"Favorites" => "Favoratoj",
"Shared by {owner}" => "Kunhavigita de {owner}",
"Result: " => "Rezulto: ",
" imported, " => " enportoj, ",
" failed." => "malsukcesoj.",
"Displayname cannot be empty." => "Montronomo devas ne esti malplena.",
"Show CardDav link" => "Montri CardDav-ligilon",
"Show read-only VCF link" => "Montri nur legeblan VCF-ligilon",
"Download" => "Elŝuti",
"Edit" => "Redakti",
"Delete" => "Forigi",
"Cancel" => "Nuligi",
"More..." => "Pli...",
"Less..." => "Malpli...",
"You do not have the permissions to read this addressbook." => "Vi ne havas la permeson legi ĉi tiun adresaron.",
"You do not have the permissions to update this addressbook." => "Vi ne havas la permeson ĝisdatigi ĉi tiun adresaron.",
"There was an error updating the addressbook." => "Eraro okazis dum ĝisdatiĝis la adresaro.",
"You do not have the permissions to delete this addressbook." => "Vi ne havas la permeson forigi ĉi tiun adresaron.",
"There was an error deleting this addressbook." => "Eraro okazis dum foriĝis ĉi tiu adresaro.",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Tvitero",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Vizaĝlibro",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo!",
"Skype" => "Skajpo",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Laboro",
"Home" => "Hejmo",
"Other" => "Alia",
"Mobile" => "Poŝtelefono",
"Text" => "Teksto",
"Voice" => "Voĉo",
"Message" => "Mesaĝo",
"Fax" => "Fakso",
"Video" => "Videaĵo",
"Pager" => "Televokilo",
"Internet" => "Interreto",
"Friends" => "Amikoj",
"Family" => "Familio",
"There was an error deleting properties for this contact." => "Eraro okazis dum forigo de propraĵoj de tiu ĉi kontakto.",
"{name}'s Birthday" => "Naskiĝtago de {name}",
"Contact" => "Kontakto",
"You do not have the permissions to add contacts to this addressbook." => "Vi ne havas la permeson aldoni kontaktojn al ĉi tiu adresaro.",
"Could not find the vCard with ID." => "Ne troviĝis vCard kun tiu identigilo.",
"You do not have the permissions to edit this contact." => "Vi ne havas permeson redakti ĉi tiun kontakton.",
"Could not find the vCard with ID: " => "Ne troviĝis vCard kun ĉi tiu identigilo:",
"Could not find the Addressbook with ID: " => "Ne troviĝis adresaro kun ĉi tiu identigilo:",
"You do not have the permissions to delete this contact." => "Vi ne havas permeson forigi ĉi tiun kontakton.",
"There was an error deleting this contact." => "Eraro okazis dum foriĝis ĉi tiu kontakto.",
"Contact not found." => "Kontakto ne troviĝis.",
"HomePage" => "Hejmpaĝo",
"New Group" => "Nova grupo",
"Settings" => "Agordo",
"Address books" => "Adresaroj",
"Import" => "Enporti",
"Select files to import" => "Elekti dosierojn por enporti",
"Select files" => "Elekti dosierojn",
"Import into:" => "Enporti en:",
"OK" => "Akcepti",
"(De-)select all" => "(Mal)elekti ĉion",
"New Contact" => "Nova kontakto",
"Download Contact(s)" => "Elŝuti kontakto(j)n",
"Groups" => "Grupoj",
"Favorite" => "Favorato",
"Delete Contact" => "Forigi kontakton",
"Close" => "Fermi",
"Keyboard shortcuts" => "Fulmoklavoj",
"Navigation" => "Navigado",
"Next contact in list" => "Jena kontakto en la listo",
"Previous contact in list" => "Maljena kontakto en la listo",
"Expand/collapse current addressbook" => "Etendi/Maletendi la nunan adresaron",
"Next addressbook" => "Jena adresaro",
"Previous addressbook" => "Maljena adresaro",
"Actions" => "Agoj",
"Refresh contacts list" => "Refreŝigi la kontaktoliston",
"Add new contact" => "Aldoni novan kontakton",
"Add new addressbook" => "Aldoni novan adresaron",
"Delete current contact" => "Forigi la nunan kontakton",
"<h3>You have no contacts in your addressbook.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>Vi havas neniun kontakton en via adresaro.</h3><p>Aldonu novan kontakton aŭ enporti ekzistantajn kontaktojn el VCF-dosiero.</p>",
"Add contact" => "Aldoni kontakton",
"Compose mail" => "Redakti retpoŝtomesaĝon",
"Delete group" => "Forigi grupon",
"Delete current photo" => "Forigi nunan foton",
"Edit current photo" => "Redakti nunan foton",
"Upload new photo" => "Alŝuti novan foton",
"Select photo from ownCloud" => "Elekti foton el ownCloud",
"First name" => "Persona nomo",
"Additional names" => "Pliaj nomoj",
"Last name" => "Familia nomo",
"Select groups" => "Elekti grupojn",
"Nickname" => "Kromnomo",
"Enter nickname" => "Enigu kromnomon",
"Title" => "Titolo",
"Enter title" => "Enigi titolon",
"Organization" => "Organizaĵo",
"Enter organization" => "Enigi organizaĵon",
"Birthday" => "Naskiĝotago",
"Notes go here..." => "Notoj iras tie ĉi...",
"Export as VCF" => "Malenporti kiel VCF",
"Add" => "Aldoni",
"Phone" => "Telefono",
"Email" => "Retpoŝtadreso",
"Instant Messaging" => "Tujmesaĝado",
"Address" => "Adreso",
"Note" => "Noto",
"Web site" => "TTT-ejo",
"Delete contact" => "Forigi kontakton",
"Preferred" => "Preferata",
"Please specify a valid email address." => "Bonvolu specifi validan retpoŝtadreson.",
"someone@example.com" => "iu@example.com",
"Mail to address" => "Retpoŝtmesaĝo al adreso",
"Delete email address" => "Forigi retpoŝþadreson",
"Enter phone number" => "Enigi telefonnumeron",
"Delete phone number" => "Forigi telefonnumeron",
"Go to web site" => "Iri al TTT-ejon",
"Delete URL" => "Forigi URL-on",
"View on map" => "Vidi en mapo",
"Delete address" => "Forigi adreson",
"1 Main Street" => "1 Ĉefa Strato",
"Street address" => "Stratadreso",
"12345" => "12345",
"Postal code" => "Poŝtkodo",
"Your city" => "Via urbo",
"City" => "Urbo",
"Some region" => "Iu regiono",
"State or province" => "Subŝtato aŭ provinco",
"Your country" => "Via lando",
"Country" => "Lando",
"Instant Messenger" => "Tujmesaĝilo",
"Delete IM" => "Forigi tujmesaĝadon",
"Share" => "Kunhavigi",
"Export" => "Elporti",
"CardDAV link" => "CardDAV-ligilo",
"The temporary image has been removed from cache." => "La provizora bildo estas forigita de la kaŝmemoro.",
"CardDAV syncing addresses" => "adresoj por CardDAV-sinkronigo",
"more info" => "pli da informo",
"Primary address (Kontact et al)" => "Ĉefa adreso (por Kontakt kaj aliaj)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Adresaroj",
"New Address Book" => "Nova adresaro",
"Name" => "Nomo",
"Description" => "Priskribo",
"Save" => "Konservi"
);
